@@ -17,7 +17,6 @@ import errno
 import functools
 import json
 import os
-import sys
 
 import mock
 from oslotest import base
@@ -29,12 +28,14 @@ from glean import cmd
 sample_data_path = os.path.join(
     os.path.dirname(os.path.realpath(__file__)), 'fixtures')
 
-distros = ['Ubuntu', 'Debian', 'Fedora', 'RedHat', 'CentOS', 'Gentoo']
-styles = ['hp', 'rax', 'rax-iad', 'liberty', 'nokey']
+distros = ['Ubuntu', 'Debian', 'Fedora', 'RedHat', 'CentOS', 'Gentoo',
+           'openSUSE', 'networkd']
+styles = ['hp', 'rax', 'rax-iad', 'liberty', 'nokey', 'ovh']
 ips = {'hp': '127.0.1.1',
        'rax': '23.253.229.154',
        'rax-iad': '146.20.110.113',
        'liberty': '23.253.229.154',
+       'ovh': '158.69.65.118',
        'nokey': '127.0.1.1'}
 
 built_scenarios = []
@@ -80,8 +81,10 @@ class TestGlean(base.BaseTestCase):
         # them in file_handle_mocks{} so we can assert they were
         # called later
         mock_dirs = ('/etc/network', '/etc/sysconfig/network-scripts',
-                     '/etc/conf.d', '/etc/init.d')
-        mock_files = ('/etc/resolv.conf', '/etc/hostname', '/etc/hosts')
+                     '/etc/conf.d', '/etc/init.d', '/etc/sysconfig/network',
+                     '/etc/systemd/network')
+        mock_files = ('/etc/resolv.conf', '/etc/hostname', '/etc/hosts',
+                      '/bin/systemctl')
         if (path.startswith(mock_dirs) or path in mock_files):
             try:
                 mock_handle = self.file_handle_mocks[path]
@@ -124,28 +127,28 @@ class TestGlean(base.BaseTestCase):
             path = os.path.join(sample_data_path, sample_prefix, path[1:])
         if path in ('/etc/sysconfig/network-scripts/ifcfg-eth2',
                     '/etc/network/interfaces.d/eth2.cfg',
-                    '/etc/conf.d/net.eth2'):
+                    '/etc/conf.d/net.eth2',
+                    '/etc/sysconfig/network/ifcfg-eth2',
+                    '/etc/systemd/network/eth2.network'):
             # Pretend this file exists, we need to test skipping
             # pre-existing config files
             return True
         elif (path.startswith(('/etc/sysconfig/network-scripts/',
+                               '/etc/sysconfig/network/',
                                '/etc/network/interfaces.d/',
-                               '/etc/conf.d/'))):
+                               '/etc/conf.d/',
+                               '/etc/systemd/network/'))):
             # Don't check the host os's network config
             return False
         return real_path_exists(path)
 
-    @mock.patch('platform.dist', new_callable=mock.Mock)
     @mock.patch('subprocess.call', return_value=0, new_callable=mock.Mock)
-    @mock.patch('subprocess.check_output', return_value=0,
-                new_callable=mock.Mock)
     @mock.patch('os.unlink', return_value=0, new_callable=mock.Mock)
     @mock.patch('os.symlink', return_value=0, new_callable=mock.Mock)
     @mock.patch('os.path.exists', new_callable=mock.Mock)
     @mock.patch('os.listdir', new_callable=mock.Mock)
     @mock.patch('os.system', return_value=0, new_callable=mock.Mock)
     @mock.patch('glean.cmd.open', new_callable=mock.Mock)
-    @mock.patch.object(sys, 'argv', ['./glean', '--hostname'])
     def _assert_distro_provider(self, distro, provider, interface,
                                 mock_open,
                                 mock_os_system,
@@ -153,19 +156,19 @@ class TestGlean(base.BaseTestCase):
                                 mock_os_path_exists,
                                 mock_os_symlink,
                                 mock_os_unlink,
-                                mock_check_output,
                                 mock_call,
-                                mock_platform_dist):
+                                skip_dns=False,
+                                use_nm=False):
         """Main test function
 
-        :param distro: distro to return from "platform.dist"
+        :param distro: distro to return from "distro.linux_distribution()"
         :param provider: we will look in fixtures/provider for mocked
                          out files
         :param interface: --interface argument; None for no argument
+        :param skip_dns: --skip-dns argument; False for no argument
+        :param use_nm: --use-nm argument; False for no argument
         """
 
-        mock_platform_dist.return_value = (distro, '', '')
-
         # These functions are watching the path and faking results
         # based on various things
         # XXX : There are several virtual file-systems available, we
@@ -179,17 +182,32 @@ class TestGlean(base.BaseTestCase):
         mock_open.side_effect = functools.partial(
             self.open_side_effect, provider)
 
-        if interface:
-            sys.argv.append('--interface=%s' % interface)
+        # default args
+        argv = ['--hostname']
 
-        cmd.main()
+        argv.append('--distro=%s' % distro.lower())
+
+        if interface:
+            argv.append('--interface=%s' % interface)
+        if skip_dns:
+            argv.append('--skip-dns')
+        if use_nm:
+            argv.append('--use-nm')
+
+        cmd.main(argv)
 
         output_filename = '%s.%s.network.out' % (provider, distro.lower())
         output_path = os.path.join(sample_data_path, 'test', output_filename)
 
         # Generate a list of (dest, content) into write_blocks to assert
         write_blocks = []
-        lines = open(output_path).readlines()
+        lines = []
+        with open(output_path) as f:
+            for line in f:
+                if line == '%NM_CONTROLLED%\n':
+                        line = 'NM_CONTROLLED=%s\n' % \
+                            ("yes" if use_nm else "no")
+                lines.append(line)
         write_dest = None
         write_content = None
         for line in lines:
@@ -207,6 +225,10 @@ class TestGlean(base.BaseTestCase):
             if interface and interface not in dest:
                 continue
             self.assertNotIn("eth2", dest)
+            # Skip check
+            if skip_dns and '/etc/resolv.conf' in dest:
+                self.assertNotIn(dest, self.file_handle_mocks)
+                continue
             self.assertIn(dest, self.file_handle_mocks)
             write_handle = self.file_handle_mocks[dest].write
             write_handle.assert_called_once_with(content)
@@ -250,3 +272,13 @@ class TestGlean(base.BaseTestCase):
     def test_glean_systemd(self):
         with mock.patch('glean.systemlock.Lock'):
             self._assert_distro_provider(self.distro, self.style, 'eth0')
+
+    def test_glean_skip_dns(self):
+        with mock.patch('glean.systemlock.Lock'):
+            self._assert_distro_provider(
+                self.distro, self.style, None, skip_dns=True)
+
+    def test_glean_nm(self):
+        with mock.patch('glean.systemlock.Lock'):
+            self._assert_distro_provider(
+                self.distro, self.style, 'eth0', use_nm=True)
